@@ -6,6 +6,8 @@ from httpx import codes
 
 from classiq_interface.server import authentication
 
+from classiq.exceptions import ClassiqAuthenticationError
+
 
 class Auth0:
     _SDK_CLIENT_ID = "f6721qMOVoDAOVkzrv8YaWassRKSFX6Y"
@@ -29,7 +31,7 @@ class Auth0:
         if code == codes.OK or error_code_allowed:
             return data
 
-        raise Exception(
+        raise ClassiqAuthenticationError(
             f"Request to Auth0 failed with error code {code}: {data.get('error')}"
         )
 
@@ -65,14 +67,14 @@ class Auth0:
 
     @staticmethod
     def refresh_access_token(refresh_token: str):
-        payload = json.dumps(
-            {
-                "client_id": Auth0._SDK_CLIENT_ID,
-                "grant_type": "refresh_token",
-                "refresh_token": refresh_token,
-            }
+        payload = (
+            f"client_id={Auth0._SDK_CLIENT_ID}&"
+            f"grant_type=refresh_token&"
+            f"refresh_token={refresh_token}"
         )
 
         return Auth0._make_request(
-            url="/oauth/token", payload=payload, content_type="application/json"
+            url="/oauth/token",
+            payload=payload,
+            content_type="application/x-www-form-urlencoded",
         )
