@@ -1,7 +1,7 @@
 import argparse
 from typing import Optional
 
-from classiq.authentication import password_manager as pm, auth0
+from classiq.authentication import auth0, password_manager as pm
 
 
 class TokenManager:
