@@ -1,12 +1,14 @@
 import ssl
-from typing import Optional, Dict, Union
+from typing import Dict, Optional, Union
 
 import httpx
 import websockets.client
+
 from classiq_interface.server import authentication
 
 from classiq import config
 from classiq.authentication import token_manager
+from classiq.exceptions import ClassiqAPIError, ClassiqExpiredTokenError
 
 
 class Client:
@@ -34,9 +36,9 @@ class Client:
             )
 
             if expired:
-                raise ExpiredTokenError("Expired token.")
+                raise ClassiqExpiredTokenError("Expired token.")
 
-            raise Exception(
+            raise ClassiqAPIError(
                 f"Call to API failed with code {response.status_code}: "
                 f"{response.json()['detail']}"
             )
@@ -71,10 +73,6 @@ class Client:
         return self._config.host
 
 
-class ExpiredTokenError(Exception):
-    pass
-
-
 DEFAULT_CLIENT = None
 
 
