@@ -1,6 +1,9 @@
-from typing import Optional
+import asyncio
+from typing import List, Optional
+
 from pyomo.core import ConcreteModel
 
+from classiq_interface import status
 from classiq_interface.backend.backend_preferences import (
     BackendPreferences,
     IBMBackendPreferences,
@@ -9,14 +12,19 @@ from classiq_interface.chemistry import operator
 from classiq_interface.combinatorial_optimization import (
     model_serializer,
     optimization_problem,
+    sense,
 )
-from classiq_interface.generator.result import GenerationResult
-from classiq_interface.hybrid import result as hybrid_result
+from classiq_interface.executor.result import ExecutionData, ExecutionStatus
 from classiq_interface.generator import result as generator_result
+from classiq_interface.generator.result import GeneratedCircuit
 from classiq_interface.hybrid import vqe_problem
-from classiq import api_wrapper
 
-from classiq_interface.hybrid.result import HybridResult
+from classiq import api_wrapper
+from classiq.exceptions import (
+    ClassiqError,
+    ClassiqExecutionError,
+    ClassiqGenerationError,
+)
 
 
 class CombinatorialOptimization:
@@ -33,6 +41,7 @@ class CombinatorialOptimization:
                 backend_service_provider="IBMQ", backend_name="aer_simulator"
             )
 
+        self.is_maximization = sense.is_maximization(model)
         self._serialized_model = model_serializer.to_json(model, return_dict=True)
         self._problem = optimization_problem.OptimizationProblem(
             serialized_model=self._serialized_model,
@@ -40,35 +49,62 @@ class CombinatorialOptimization:
             backend_preferences=backend_preferences,
         )
 
-    async def generate(self) -> GenerationResult:
+    def generate(self) -> GeneratedCircuit:
+        return asyncio.run(self.generate_async())
+
+    async def generate_async(self) -> GeneratedCircuit:
+        """Async version of `generate`"""
         wrapper = api_wrapper.ApiWrapper()
         result = await wrapper.call_combinatorial_optimization_generate_task(
             problem=self._problem
         )
 
         if result.status != generator_result.GenerationStatus.SUCCESS:
-            raise Exception(f"Solving failed: {result.details}")
+            raise ClassiqGenerationError(f"Solving failed: {result.details}")
 
-        return result
+        return result.details
 
-    async def solve(self) -> HybridResult:
+    def solve(self) -> ExecutionData:
+        return asyncio.run(self.solve_async())
+
+    async def solve_async(self) -> ExecutionData:
+        """Async version of `solve`"""
         wrapper = api_wrapper.ApiWrapper()
         result = await wrapper.call_combinatorial_optimization_solve_task(
             problem=self._problem
         )
 
-        if result.status != hybrid_result.HybridStatus.SUCCESS:
-            raise Exception(f"Solving failed: {result.details}")
+        if result.status != ExecutionStatus.SUCCESS:
+            raise ClassiqExecutionError(f"Solving failed: {result.details}")
 
-        return result
+        return result.details
 
-    async def get_operator(self) -> operator.OperatorResult:
+    def get_operator(self) -> operator.OperatorResult:
+        return asyncio.run(self.get_operator_async())
+
+    async def get_operator_async(self) -> operator.PauliOperator:
+        """Async version of `get_operator`"""
         wrapper = api_wrapper.ApiWrapper()
         result = await wrapper.call_combinatorial_optimization_operator_task(
             problem=self._problem
         )
 
         if result.status != operator.OperatorStatus.SUCCESS:
-            raise Exception(f"Get operator failed: {result.details}")
+            raise ClassiqError(f"Get operator failed: {result.details}")
 
-        return result
+        return result.details
+
+    def get_initial_point(self) -> List[float]:
+        return asyncio.run(self.get_initial_point_async())
+
+    async def get_initial_point_async(self) -> List[float]:
+        """Async version of `get_initial_point`"""
+        wrapper = api_wrapper.ApiWrapper()
+        result = await wrapper.call_combinatorial_optimization_initial_point_task(
+            problem=self._problem
+        )
+
+        if result.status != status.Status.SUCCESS:
+            raise ClassiqError(f"Get inital point failed: {result.details}")
+
+        return result.details
