@@ -1,17 +1,20 @@
 """Generator module, implementing facilities for generating circuits using Classiq platform."""
+import asyncio
 import functools
-from enum import Enum
-from typing import Optional, Dict
+from typing import Dict, Optional
 
-from classiq import api_wrapper, wire
 from classiq_interface.generator import (
     constraints,
-    result,
-    segments,
+    function_call,
     function_param_list,
     function_params,
+    result,
 )
+from classiq_interface.generator.custom_functions.custom_function import CustomFunction
 
+from classiq import api_wrapper, wire
+from classiq.custom_function_library import CustomFunctionLibrary
+from classiq.exceptions import ClassiqGenerationError, ClassiqValueError
 
 # TODO: Add docstrings for auto generated methods.
 
@@ -30,9 +33,18 @@ class Generator:
             qubit_count=qubit_count, max_depth=max_depth, **kwargs
         )
 
-    async def generate(self) -> result.GeneratedCircuit:
+    def generate(self) -> result.GeneratedCircuit:
         """Generates a circuit, based on the aggregation of requirements in self.
 
+        Returns:
+            The results of the generation procedure.
+        """
+        return asyncio.run(self.generate_async())
+
+    async def generate_async(self) -> result.GeneratedCircuit:
+        """Async version of `generate`
+        Generates a circuit, based on the aggregation of requirements in self.
+
         Returns:
             The results of the generation procedure.
         """
@@ -42,7 +54,9 @@ class Generator:
         generation_result = await wrapper.call_generation_task(self._constraints)
 
         if generation_result.status != result.GenerationStatus.SUCCESS:
-            raise Exception(f"Generation failed: {generation_result.details}")
+            raise ClassiqGenerationError(
+                f"Generation failed: {generation_result.details}"
+            )
 
         return generation_result.details
 
@@ -55,28 +69,47 @@ class Generator:
         """
         return self._constraints
 
-    def _add_segment(
+    def _add_function_call(
         self,
         function: str,
         params: function_params.FunctionParams,
-        in_wires: Optional[Dict[Enum, wire.Wire]] = None,
-    ) -> Dict[Enum, wire.Wire]:
+        in_wires: Optional[Dict[str, wire.Wire]] = None,
+    ) -> Dict[str, wire.Wire]:
         if function != type(params).__name__:
-            raise Exception("The FunctionParams type does not match function name")
+            raise ClassiqValueError(
+                "The FunctionParams type does not match function name"
+            )
+        if isinstance(params, CustomFunction):
+            params.validate_custom_function_in_library(
+                library=self._constraints.custom_function_library_data,
+                error_handler=ClassiqValueError,
+            )
 
-        segment = segments.FunctionCall(function=function, function_params=params)
+        call = function_call.FunctionCall(function=function, function_params=params)
 
         if in_wires:
-            for in_enum, in_wire in in_wires.items():
-                in_wire.connect_wire(end_segment=segment, input_enum=in_enum)
+            for input_name, in_wire in in_wires.items():
+                in_wire.connect_wire(end_call=call, input_name=input_name)
 
-        self._constraints.logic_flow.append(segment)
+        self._constraints.logic_flow.append(call)
 
         return {
-            out_enum: wire.Wire(start_segment=segment, output_enum=out_enum)
-            for out_enum in params.get_io_enum(function_params.IO.Output)
+            output_name: wire.Wire(start_call=call, output_name=output_name)
+            for output_name in params.get_io_names(function_params.IO.Output)
         }
 
+    def include_library(self, library: CustomFunctionLibrary) -> None:
+        """Includes a user-defined custom function library.
+
+        Args:
+            library (CustomFunctionLibrary): The custom function library.
+        """
+        if self._constraints.custom_function_library_data is not None:
+            raise ClassiqValueError(
+                "Another custom function library is already included."
+            )
+        self._constraints.custom_function_library_data = library.data
+
     def __getattribute__(self, item):
         is_item_function_name = any(
             item == func.__name__
@@ -84,7 +117,7 @@ class Generator:
         )
 
         if is_item_function_name:
-            return functools.partial(self._add_segment, function=item)
+            return functools.partial(self._add_function_call, function=item)
 
         return super().__getattribute__(item)
 
